@@ -63,7 +63,16 @@ Tries to resolve the given domain name into a list of name servers.
 
 =item AnyEvent::DNS::txt $domain, $cb->(@hostnames)
 
-Tries to resolve the given domain name into a list of text records.
+Tries to resolve the given domain name into a list of text records. Only
+the first text string per record will be returned. If you want all
+strings, you need to call the resolver manually:
+
+   resolver->resolve ($domain => "txt", sub {
+      for my $record (@_) {
+         my (undef, undef, undef, @txt) = @$record;
+         # strings now in @txt
+      }
+   });
 
 =item AnyEvent::DNS::srv $service, $proto, $domain, $cb->(@srv_rr)
 
@@ -81,21 +90,21 @@ Example:
    AnyEvent::DNS::srv "sip", "udp", "schmorp.de", sub { ...
    # @_ = ( [10, 10, 5060, "sip1.schmorp.de" ] )
 
+=item AnyEvent::DNS::any $domain, $cb->(@rrs)
+
+Tries to resolve the given domain and passes all resource records found to
+the callback.
+
 =item AnyEvent::DNS::ptr $domain, $cb->(@hostnames)
 
 Tries to make a PTR lookup on the given domain. See C<reverse_lookup>
 and C<reverse_verify> if you want to resolve an IP address to a hostname
 instead.
 
-=item AnyEvent::DNS::any $domain, $cb->(@rrs)
-
-Tries to resolve the given domain and passes all resource records found to
-the callback.
-
 =item AnyEvent::DNS::reverse_lookup $ipv4_or_6, $cb->(@hostnames)
 
 Tries to reverse-resolve the given IPv4 or IPv6 address (in textual form)
-into it's hostname(s). Handles V4MAPPED and V4COMPAT IPv6 addresses
+into its hostname(s). Handles V4MAPPED and V4COMPAT IPv6 addresses
 transparently.
 
 =item AnyEvent::DNS::reverse_verify $ipv4_or_6, $cb->(@hostnames)
@@ -111,7 +120,7 @@ address you originally resolved.
 
 Example:
 
-   AnyEvent::DNS::ptr "2001:500:2f::f", sub { print shift };
+   AnyEvent::DNS::reverse_verify "2001:500:2f::f", sub { print shift };
    # => f.root-servers.net
 
 =cut
@@ -653,10 +662,11 @@ our $NOW;
 =item AnyEvent::DNS::resolver
 
 This function creates and returns a resolver that is ready to use and
-should mimic the default resolver for your system as good as possible.
+should mimic the default resolver for your system as good as possible. It
+is used by AnyEvent itself as well.
 
-It only ever creates one resolver and returns this one on subsequent
-calls.
+It only ever creates one resolver and returns this one on subsequent calls
+- see C<$AnyEvent::DNS::RESOLVER>, below, for details.
 
 Unless you have special needs, prefer this function over creating your own
 resolver object.
@@ -670,6 +680,16 @@ C<os_config> will be used for OS-specific configuration, unless
 C<$ENV{PERL_ANYEVENT_RESOLV_CONF}> is specified, in which case that file
 gets parsed.
 
+=item $AnyEvent::DNS::RESOLVER
+
+This variable stores the default resolver returned by
+C<AnyEvent::DNS::resolver>, or C<undef> when the default resolver hasn't
+been instantiated yet.
+
+One can provide a custom resolver (e.g. one with caching functionality)
+by storing it in this variable, causing all subsequent resolves done via
+C<AnyEvent::DNS::resolver> to be done via the custom one.
+
 =cut
 
 our $RESOLVER;
@@ -802,7 +822,7 @@ sub new {
 Parses the given string as if it were a F<resolv.conf> file. The following
 directives are supported (but not necessarily implemented).
 
-C<#>-style comments, C<nameserver>, C<domain>, C<search>, C<sortlist>,
+C<#>- and C<;>-style comments, C<nameserver>, C<domain>, C<search>, C<sortlist>,
 C<options> (C<timeout>, C<attempts>, C<ndots>).
 
 Everything else is silently ignored.
@@ -818,7 +838,7 @@ sub parse_resolv_conf {
    my $attempts;
 
    for (split /\n/, $resolvconf) {
-      s/#.*$//; # not quite legal, but many people insist
+      s/\s*[;#].*$//; # not quite legal, but many people insist
 
       if (/^\s*nameserver\s+(\S+)\s*$/i) {
          my $ip = $1;
@@ -827,7 +847,7 @@ sub parse_resolv_conf {
          } else {
             warn "nameserver $ip invalid and ignored\n";
          }
-      } elsif (/^\s*domain\s+(\S*)\s+$/i) {
+      } elsif (/^\s*domain\s+(\S*)\s*$/i) {
          $self->{search} = [$1];
       } elsif (/^\s*search\s+(.*?)\s*$/i) {
          $self->{search} = [split /\s+/, $1];
